{ This unit implements a Windows 95 Explorer - like double pane form with a }
{ vertical slider that adjusts the size of the two panes }
{ by Pablo Pissanetzky - pablo@neosoft.com - http://www.neosoft.com/~pablo }
{ Author of TSuperGrid - check it out the site above }

{ You can save this form as a template or place it in the object repository for }
{ reuse }

unit Main;

interface

uses
  WinTypes , WinProcs , Messages, SysUtils, Classes, Graphics, Controls,
  Forms, Dialogs, ExtCtrls;

type
  TForm1 = class(TForm)
    LeftPanel: TPanel;
    ToolBarPanel: TPanel;
    LeftCaptionPanel: TPanel;
    CenterPanel: TPanel;
    RightPanel: TPanel;
    RightCaptionPanel: TPanel;
    LeftContainerPanel: TPanel;
    RightContainerPanel: TPanel;
    procedure CenterPanelMouseDown(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure FormCreate(Sender: TObject);
    procedure CenterPanelMouseUp(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure CenterPanelMouseMove(Sender: TObject; Shift: TShiftState; X,
      Y: Integer);
    procedure FormDestroy(Sender: TObject);
  private
    MouseDownOnCenterPanel : Boolean;
    SliderPanel : TPanel;
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}
{ Create a panel that will be displayed when the user resizes }
procedure TForm1.FormCreate(Sender: TObject);
begin
  SliderPanel := TPanel.Create( Self );
  with SliderPanel do
    begin
      Parent := Self;
      Visible := False;
      BevelInner := bvNone;
      BevelOuter := bvNone;
      Caption := ' ';
      Color := clBlack;
      BevelWidth := 1;
      Cursor := crHSplit;
    end;
  MouseDownOnCenterPanel := False;
end;

{ Position and display the slider panel }
procedure TForm1.CenterPanelMouseDown(Sender: TObject;
  Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
begin
  if Button = mbLeft then
    begin
      MouseDownOnCenterPanel := True;
      SliderPanel.Top := CenterPanel.Top;
      SliderPanel.Left := CenterPanel.Left;
      SliderPanel.Height := CenterPanel.Height;
      SliderPanel.Width := CenterPanel.Width;
      SliderPanel.Visible := True;
    end;
end;

{ Move the slider panel }
{ The checks are for a minimum width of the two panes, it can be removed or }
{ altered }
procedure TForm1.CenterPanelMouseMove(Sender: TObject; Shift: TShiftState;
  X, Y: Integer);
var
  ALeft : Integer;
begin
  if MouseDownOnCenterPanel then
    begin
      ALeft := CenterPanel.Left + X;
      if ALeft < ( LeftPanel.Left + 20 ) then
        ALeft := LeftPanel.Left + 20
      else if ALeft > ( RightPanel.Left + RightPanel.Width - 20 ) then
        ALeft := RightPanel.Left + RightPanel.Width - 20;
      SliderPanel.Left := ALeft;
      Update;
    end;
end;

{ When the mouse button is released, resize the left panel, this will resize }
{ all the other panels automatically }
procedure TForm1.CenterPanelMouseUp(Sender: TObject; Button: TMouseButton;
  Shift: TShiftState; X, Y: Integer);
begin
  if MouseDownOnCenterPanel then
    begin
      MouseDownOnCenterPanel := False;
      SliderPanel.Visible := False;
      LeftPanel.Width := SliderPanel.Left - 1;
      Update;
    end;
end;

{ Finally, free the slider panel we created }
procedure TForm1.FormDestroy(Sender: TObject);
begin
  SliderPanel.Free;
end;

end.
